pub trait AsyncPushSender:
Send
+ Sync
+ 'static {
// Required method
fn send(&self, info: PushInfo) -> Result<(), SendError>;
}Expand description
A trait for sender parts of a channel that can be used for sending push messages from async connection.
Required Methods
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".